# Secrets Management

Secure secret resolution and notification setup.

## Files

- secrets_management_demo.ipynb
- secrets_management.yaml
- notifications_and_secrets/notifications_secrets.ipynb
- notifications_and_secrets/notifications_contract.yaml
